@@ -279,8 +279,8 @@ public abstract class Supervisor extends HttpServlet {
 						fw = onIllegalRequest( IllegalRequest.SESSION_ERROR, req, path_data.from, path_data.to );
 						if ( fw != null ) {
 							session_f = fw.session_clear_f;
-							last_page = fact.getNullPage();
-							next_page = fw.getPage( null );
+							path_data.from = last_page = null;
+							path_data.to = next_page = fw.getPage( null );
 							if ( next_page == null ) {
 								fw.Action( this, res );
 								if ( session_f )	if (session != null )	session.invalidate();
@@ -439,7 +439,7 @@ public abstract class Supervisor extends HttpServlet {
 			session.setAttribute( SESSION_DATA, data );
 		}
 		holder.myself = next_page.getID();
-		if ( param.getMethod() == RequestParameter.Method.POST ) {
+		if ( !session_f && param.getMethod() == RequestParameter.Method.POST ) {
 			data.redirect( out_ret, fw, holder ).Action( this, res );
 		}
 		else {
